@@ -1,9 +1,9 @@
 /**
- * @file oaLHSUtility.cpp
+ * @file oaLHSUtility.h
  * @author Robert Carnell
  * @copyright Copyright (c) 2019, Robert Carnell
  * 
- * @license <a href="http://www.gnu.org/licenses/lgpl.html">GNU Lesser General Public License (LGPL v3)</a>
+ * License: <a href="http://www.gnu.org/licenses/lgpl.html">GNU Lesser General Public License (LGPL v3)</a>
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -26,21 +26,13 @@
 
 namespace oalhslib
 {
-    /*template <class T>
-    void findUnique(typename std::iterator<std::forward_iterator_tag, T> & begin, 
-            typename std::iterator<std::forward_iterator_tag, T> & end, 
-            typename std::vector<T> & output)
-    {
-        for (std::iterator<std::forward_iterator_tag, T> it = begin; it != end; ++it)
-        {
-            typename std::vector<T>::iterator tempit = std::find(output.begin(), output.end(), *it);
-            if (tempit ==  output.end())
-            {
-                output.push_back(*it);
-            }
-        }
-    }*/
-
+	/**
+	 * The the unique column elements of a matrix
+	 *
+	 * @param A input matrix
+	 * @param U output vector of vectors of unique elements by column
+	 * @tparam T the type of elements in the input matrix A
+	 */
     template <class T>
     void findUniqueColumnElements(const bclib::matrix<T> & A, std::vector<std::vector<T> > & U)
     {
